/****************************************************************************
** GraphGridData meta object code from reading C++ file 'GraphGridData.h'
**
** Created: Thu Sep 2 20:49:13 1999
**      by: The Qt Meta Object Compiler ($Revision: 2.25.2.12 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#if !defined(Q_MOC_OUTPUT_REVISION)
#define Q_MOC_OUTPUT_REVISION 2
#elif Q_MOC_OUTPUT_REVISION != 2
#error "Moc format conflict - please regenerate all moc files"
#endif

#include "GraphGridData.h"
#include <qmetaobject.h>


const char *GraphGridData::className() const
{
    return "GraphGridData";
}

QMetaObject *GraphGridData::metaObj = 0;


#if QT_VERSION >= 200
static QMetaObjectInit init_GraphGridData(&GraphGridData::staticMetaObject);

#endif

void GraphGridData::initMetaObject()
{
    if ( metaObj )
	return;
    if ( strcmp(QWidget::className(), "QWidget") != 0 )
	badSuperclassWarning("GraphGridData","QWidget");

#if QT_VERSION >= 200
    staticMetaObject();
}

void GraphGridData::staticMetaObject()
{
    if ( metaObj )
	return;
    QWidget::staticMetaObject();
#else

    QWidget::initMetaObject();
#endif

    metaObj = new QMetaObject( "GraphGridData", "QWidget",
	0, 0,
	0, 0 );
}
